@@ -25,30 +25,30 @@
 #include "mem_pool.h"
 
 /* Public prototypes */
-struct memory_pool_s *lua_check_mempool (lua_State * L);
-gint luaopen_mempool (lua_State * L);
+struct memory_pool_s * rspamd_lua_check_mempool (lua_State * L);
+void luaopen_mempool (lua_State * L);
 
 /* Lua bindings */
 LUA_FUNCTION_DEF (mempool, create);
 LUA_FUNCTION_DEF (mempool, memory_pool_add_destructor);
 LUA_FUNCTION_DEF (mempool, memory_pool_delete);
 LUA_FUNCTION_DEF (mempool, memory_pool_stat);
-LUA_FUNCTION_DEF (mempool, memory_pool_get_size);
+LUA_FUNCTION_DEF (mempool, memory_pool_suggest_size);
 LUA_FUNCTION_DEF (mempool, memory_pool_set_variable);
 LUA_FUNCTION_DEF (mempool, memory_pool_get_variable);
 
-static const struct luaL_reg    mempoollib_m[] = {
+static const struct luaL_reg mempoollib_m[] = {
 	LUA_INTERFACE_DEF (mempool, memory_pool_add_destructor),
 	LUA_INTERFACE_DEF (mempool, memory_pool_stat),
-	LUA_INTERFACE_DEF (mempool, memory_pool_get_size),
+	LUA_INTERFACE_DEF (mempool, memory_pool_suggest_size),
 	LUA_INTERFACE_DEF (mempool, memory_pool_set_variable),
 	LUA_INTERFACE_DEF (mempool, memory_pool_get_variable),
 	{"destroy", lua_mempool_memory_pool_delete},
-	{"__tostring", lua_class_tostring},
+	{"__tostring", rspamd_lua_class_tostring},
 	{NULL, NULL}
 };
 
-static const struct luaL_reg    mempoollib_f[] = {
+static const struct luaL_reg mempoollib_f[] = {
 	LUA_INTERFACE_DEF (mempool, create),
 	{NULL, NULL}
 };
@@ -60,13 +60,13 @@ static const struct luaL_reg    mempoollib_f[] = {
 struct lua_mempool_udata {
 	lua_State *L;
 	gint cbref;
-	memory_pool_t *mempool;
+	rspamd_mempool_t *mempool;
 };
 
-struct memory_pool_s      *
-lua_check_mempool (lua_State * L)
+struct memory_pool_s *
+rspamd_lua_check_mempool (lua_State * L)
 {
-	void								*ud = luaL_checkudata (L, 1, "rspamd{mempool}");
+	void *ud = luaL_checkudata (L, 1, "rspamd{mempool}");
 	luaL_argcheck (L, ud != NULL, 1, "'mempool' expected");
 	return ud ? *((struct memory_pool_s **)ud) : NULL;
 }
@@ -75,11 +75,12 @@ lua_check_mempool (lua_State * L)
 static int
 lua_mempool_create (lua_State *L)
 {
-	struct memory_pool_s					*mempool = memory_pool_new (memory_pool_get_size ()), **pmempool;
+	struct memory_pool_s *mempool = rspamd_mempool_new (
+		rspamd_mempool_suggest_size ()), **pmempool;
 
 	if (mempool) {
 		pmempool = lua_newuserdata (L, sizeof (struct memory_pool_s *));
-		lua_setclass (L, "rspamd{mempool}", -1);
+		rspamd_lua_setclass (L, "rspamd{mempool}", -1);
 		*pmempool = mempool;
 	}
 	else {
@@ -92,7 +93,7 @@ lua_mempool_create (lua_State *L)
 static void
 lua_mempool_destructor_func (gpointer p)
 {
-	struct lua_mempool_udata				*ud = p;
+	struct lua_mempool_udata *ud = p;
 
 	lua_rawgeti (ud->L, LUA_REGISTRYINDEX, ud->cbref);
 	if (lua_pcall (ud->L, 0, 0, 0) != 0) {
@@ -104,18 +105,21 @@ lua_mempool_destructor_func (gpointer p)
 static int
 lua_mempool_memory_pool_add_destructor (lua_State *L)
 {
-	struct memory_pool_s					*mempool = lua_check_mempool (L);
-	struct lua_mempool_udata				*ud;
+	struct memory_pool_s *mempool = rspamd_lua_check_mempool (L);
+	struct lua_mempool_udata *ud;
 
 	if (mempool) {
 		if (lua_isfunction (L, 2)) {
-			ud = memory_pool_alloc (mempool, sizeof (struct lua_mempool_udata));
+			ud = rspamd_mempool_alloc (mempool,
+					sizeof (struct lua_mempool_udata));
 			lua_pushvalue (L, 2);
 			/* Get a reference */
 			ud->cbref = luaL_ref (L, LUA_REGISTRYINDEX);
 			ud->L = L;
 			ud->mempool = mempool;
-			memory_pool_add_destructor (mempool, lua_mempool_destructor_func, ud);
+			rspamd_mempool_add_destructor (mempool,
+				lua_mempool_destructor_func,
+				ud);
 		}
 		else {
 			msg_err ("trying to add destructor without function");
@@ -131,10 +135,10 @@ lua_mempool_memory_pool_add_destructor (lua_State *L)
 static int
 lua_mempool_memory_pool_delete (lua_State *L)
 {
-	struct memory_pool_s					*mempool = lua_check_mempool (L);
+	struct memory_pool_s *mempool = rspamd_lua_check_mempool (L);
 
 	if (mempool) {
-		memory_pool_delete (mempool);
+		rspamd_mempool_delete (mempool);
 		return 0;
 	}
 	else {
@@ -147,10 +151,10 @@ lua_mempool_memory_pool_delete (lua_State *L)
 static int
 lua_mempool_memory_pool_stat (lua_State *L)
 {
-	struct memory_pool_s					*mempool = lua_check_mempool (L);
+	struct memory_pool_s *mempool = rspamd_lua_check_mempool (L);
 
 	if (mempool) {
-		
+
 	}
 	else {
 		lua_pushnil (L);
@@ -160,12 +164,12 @@ lua_mempool_memory_pool_stat (lua_State *L)
 }
 
 static int
-lua_mempool_memory_pool_get_size (lua_State *L)
+lua_mempool_memory_pool_suggest_size (lua_State *L)
 {
-	struct memory_pool_s					*mempool = lua_check_mempool (L);
+	struct memory_pool_s *mempool = rspamd_lua_check_mempool (L);
 
 	if (mempool) {
-		lua_pushinteger (L, memory_pool_get_size ());
+		lua_pushinteger (L, rspamd_mempool_suggest_size ());
 		return 0;
 	}
 	else {
@@ -178,12 +182,13 @@ lua_mempool_memory_pool_get_size (lua_State *L)
 static int
 lua_mempool_memory_pool_set_variable (lua_State *L)
 {
-	struct memory_pool_s					*mempool = lua_check_mempool (L);
-	const gchar								*var = luaL_checkstring (L, 2),
-											*value = luaL_checkstring (L, 3);
+	struct memory_pool_s *mempool = rspamd_lua_check_mempool (L);
+	const gchar *var = luaL_checkstring (L, 2),
+	*value = luaL_checkstring (L, 3);
 
 	if (mempool && var && value) {
-		memory_pool_set_variable (mempool, var, memory_pool_strdup (mempool, value), NULL);
+		rspamd_mempool_set_variable (mempool, var,
+			rspamd_mempool_strdup (mempool, value), NULL);
 		return 0;
 	}
 	else {
@@ -196,12 +201,12 @@ lua_mempool_memory_pool_set_variable (lua_State *L)
 static int
 lua_mempool_memory_pool_get_variable (lua_State *L)
 {
-	struct memory_pool_s					*mempool = lua_check_mempool (L);
-	const gchar								*var = luaL_checkstring (L, 2);
-	gchar									*value;
+	struct memory_pool_s *mempool = rspamd_lua_check_mempool (L);
+	const gchar *var = luaL_checkstring (L, 2);
+	gchar *value;
 
 	if (mempool && var) {
-		value = memory_pool_get_variable (mempool, var);
+		value = rspamd_mempool_get_variable (mempool, var);
 		if (value) {
 			lua_pushstring (L, value);
 		}
@@ -216,7 +221,16 @@ lua_mempool_memory_pool_get_variable (lua_State *L)
 	return 1;
 }
 
-gint
+static gint
+lua_load_mempool (lua_State * L)
+{
+	lua_newtable (L);
+	luaL_register (L, NULL, mempoollib_f);
+
+	return 1;
+}
+
+void
 luaopen_mempool (lua_State * L)
 {
 	luaL_newmetatable (L, "rspamd{mempool}");
@@ -228,10 +242,8 @@ luaopen_mempool (lua_State * L)
 	lua_pushstring (L, "rspamd{mempool}");
 	lua_rawset (L, -3);
 
-	luaL_register (L, NULL, mempoollib_m);
-	luaL_register (L, "rspamd_mempool", mempoollib_f);
+	luaL_register (L, NULL,				mempoollib_m);
+	rspamd_lua_add_preload (L, "rspamd_mempool", lua_load_mempool);
 
 	lua_pop (L, 1);                      /* remove metatable from stack */
-
-	return 1;	
 }
