@@ -8,9 +8,6 @@
 /* URL parser test */
 void rspamd_url_test_func (void);
 
-/* Memcached library test */
-void rspamd_memcached_test_func (void);
-
 /* Memory pools */
 void rspamd_mem_pool_test_func (void);
 
@@ -23,6 +20,9 @@ void rspamd_fuzzy_test_func (void);
 /* Stat file */
 void rspamd_statfile_test_func (void);
 
+/* Radix test */
+void rspamd_radix_test_func (void);
+
 /* DNS resolving */
 void rspamd_dns_test_func (void);
 
@@ -35,7 +35,8 @@ void rspamd_dkim_test_func (void);
 /* RRD test */
 void rspamd_rrd_test_func (void);
 
-/* RCL test */
-void rspamd_rcl_test_func (void);
+void rspamd_upstream_test_func (void);
+
+void rspamd_shingles_test_func (void);
 
 #endif
